from session1.functions import is_perfect_square


class ClassToTest:

    @staticmethod
    def call_perfect_square(num: int):
        return is_perfect_square(num)


print(f'Hey: {ClassToTest.call_perfect_square(4)}')




import pandas as pd


def average_price_in(df, neighbourhood):
    df_private_rooms_in_brooklyn = df.loc[
        (df['neighbourhood_group'] == neighbourhood) & (df['room_type'] == 'Private room')]
    avg_price = df_private_rooms_in_brooklyn['price'].mean()
    return avg_price


if __name__ == "__main__":
    df = pd.read_csv('AB_NYC_2019.csv')
    print(df['room_type'].head())
    print(df.columns)

    print(f' The avg price is ${average_price_in(df,"Brooklyn")}')



import math


def get_double(num: int):
    return num * 2


def display_date(day, month, year):
    print(f'{day}/{month}/{year}')


def is_positive(num: int):
    return num >= 0


def is_perfect_square(num: int):
    sqr_root = num ** (1 / 2)
    return sqr_root - int(sqr_root) == 0 and num > 0


def get_sphere_vol(radius: float):
    return 4 / 3 * math.pi * radius ** 3


def celsius_to_fahrenheit(temp: float):
    return temp * (9 / 5) + 32


if __name__ == "__main__":header=None
    print(get_double(4))

    display_date(24, 10, 2019)

    print(is_positive(8))
    print(is_positive(-8))

    print(is_perfect_square(4))
    print(is_perfect_square(5))

    print(get_sphere_vol(4))

    print(celsius_to_fahrenheit(21))





import logging

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)

logger.log(level=logging.INFO, msg=f'Starting program')
while True:
    weight = float(input('Weight: '))
    if weight == 1:
        logger.log(level=logging.INFO, msg=f'Exiting program')
        break
    logger.log(level=logging.INFO, msg=f'Weight is {weight}')
    height = float(input('Height: '))
    logger.log(level=logging.INFO, msg=f'Height is {height}')

    bmi = weight / height**2
    logger.log(level=logging.INFO, msg=f'BMI is {int(bmi)}%')




from session2.exercise2.cars.sample import bmw, mercedes, renault


def list_cars_by_brand(brand_name):
    brand_list = {
        'bmw': bmw,
        'mercedes': mercedes,
        'renault': renault
    }

    if brand_name.lower() in brand_list.keys():
        for model in brand_list[brand_name.lower()].car_models:
            print(model)
    else:
        print('This car is not in our catalogue')


while True:
    brand = input('Type a brand name to list cars: ')
    if brand == 'exit': break
    list_cars_by_brand(brand)



import math


def return_highest(a: int, b: int):
    return a if a > b else b


def square_or_square_root(a: int):
    return a**(1/2) if a > 0 else a**2


def even_or_odd(num: int):
    return 'even' if num % 2 == 0 else 'odd'


def get_percentage(salary: float, bills: float):
    return bills/salary


def get_car_price(factory_cost: float):
    taxes = 0
    distributor = 0

    if factory_cost < 12000:
        taxes = 0
        distributor = factory_cost * 0.05

    elif factory_cost < 25000:
        taxes = factory_cost * 0.15
        distributor = factory_cost * 0.10
    else:
        taxes = factory_cost * 0.10
        distributor = factory_cost * 0.15

    return factory_cost + distributor + taxes


print(return_highest(2, 3))
print(return_highest(5, 3))

print(square_or_square_root(-3))
print(square_or_square_root(4))

print(even_or_odd(8))
print(even_or_odd(15))

print(get_percentage(1231, 12))

print(get_car_price(12314))



from session2.exercise2.cars.bmw import Bmw
from session2.exercise2.cars.mercedes import Mercedes
from session2.exercise2.cars.renault import Renault


bmw = Bmw()
mercedes = Mercedes()
renault = Renault()





from session2.exercise1.count_letters_module import count_letters
from session2.exercise1.calculate_power_module import power
from session2.exercise1.calculate_square_root_module import square_root


print(count_letters())

print(power(2, 2))

print(square_root(16))



import unittest
from parameterized import parameterized
from session1.class_to_test import ClassToTest


class TestClassToTest(unittest.TestCase):

    def setUp(self) -> None:
        self.class_to_test = ClassToTest()

    @parameterized.expand([
        [1, 8],
        [4, 13],
        [16, 236],
    ])
    def test_call_perfect_square(self, num_true, num_false):
        assert self.class_to_test.call_perfect_square(num_true) is True
        assert self.class_to_test.call_perfect_square(num_false) is False



import setuptools

with open("README.md", 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='David carlist',
    version="0.0.1",
    author="David",
    author_email="randomail@hehe.com",
    description='list of cars for training purposes',
    long_description = long_description,
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ]
)

